"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.rightNow = rightNow;
exports.relativeTicks = relativeTicks;
exports.seconds = seconds;
exports.relativeSeconds = relativeSeconds;
exports.minutes = minutes;
exports.relativeMinutes = relativeMinutes;
exports.hours = hours;
exports.hoursAndMinutes = hoursAndMinutes;
exports.yesterdayOrTommorow = yesterdayOrTommorow;
exports.relativeHoursAndMinutes = relativeHoursAndMinutes;
exports.relativeDelta = relativeDelta;
exports.weekdayThisWeek = weekdayThisWeek;
exports.weekdayNextWeek = weekdayNextWeek;
exports.fewSeconds = fewSeconds;
exports.underMinute = underMinute;
exports.earlierOrLaterToday = earlierOrLaterToday;
exports.earlierOrLater = earlierOrLater;
exports.earlierThisWeek = earlierThisWeek;
exports.earlierLastWeek = earlierLastWeek;
exports.relativeThisWeek = relativeThisWeek;
exports.relativeSecondWeek = relativeSecondWeek;

var _index = require("./index.js");

function rightNow() {
  return 'right now';
}

function relativeTicks(_ref) {
  var past = _ref.past,
      ticks = _ref.ticks;
  return past ? "".concat(ticks, " ago") : "in ".concat(ticks);
}

function seconds(_ref2) {
  var seconds = _ref2.seconds;
  return "".concat(seconds, " ").concat(seconds > 1 ? 'seconds' : 'second');
}

function relativeSeconds(opts) {
  var ticks = seconds({
    seconds: opts.seconds
  });
  return relativeTicks({
    past: opts.past,
    ticks: ticks
  });
}

function minutes(_ref3) {
  var minutes = _ref3.minutes;
  return "".concat(minutes, " ").concat(minutes > 1 ? 'minutes' : 'minute');
}

function relativeMinutes(opts) {
  var ticks = minutes({
    minutes: opts.minutes
  });
  return relativeTicks({
    past: opts.past,
    ticks: ticks
  });
}

function hours(_ref4) {
  var hours = _ref4.hours;
  return "".concat(hours, " ").concat(hours > 1 ? 'hours' : 'hour');
}

function hoursAndMinutes(opts) {
  return hours(opts) + (opts.minutes ? ' ' + minutes(opts) : '');
}

function yesterdayOrTommorow(_ref5) {
  var past = _ref5.past;
  return past ? 'yesterday' : 'tomorrow';
}

function relativeHoursAndMinutes(opts) {
  var ticks = hoursAndMinutes({
    hours: opts.hours,
    minutes: opts.minutes
  });
  return relativeTicks({
    past: opts.past,
    ticks: ticks
  });
}

function relativeDelta(opts) {
  if (opts.delta < _index.Minute) {
    var _seconds = Math.floor(opts.delta / _index.Second);

    if (_seconds) return relativeSeconds({
      past: opts.past,
      seconds: _seconds
    });
  }

  var hours = Math.floor(opts.delta / _index.Hour);
  var minutes = Math.floor((opts.delta - hours * _index.Hour) / _index.Minute);
  if (hours) return relativeHoursAndMinutes({
    past: opts.past,
    hours: hours,
    minutes: minutes
  });
  if (minutes) return relativeMinutes({
    past: opts.past,
    minutes: minutes
  });
  return rightNow();
}

function weekdayThisWeek(_ref6) {
  var weekday = _ref6.weekday;
  return "this ".concat(weekday);
}

function weekdayNextWeek(_ref7) {
  var weekday = _ref7.weekday;
  return "next ".concat(weekday);
}

function fewSeconds(_ref8) {
  var past = _ref8.past;
  return past ? 'a few seconds ago' : 'in a few seconds';
}

function underMinute(_ref9) {
  var past = _ref9.past;
  return past ? 'under a minute ago' : 'in under a minute';
}

function earlierOrLaterToday(_ref10) {
  var past = _ref10.past;
  return past ? 'earlier today' : 'later today';
}

function earlierOrLater(_ref11) {
  var past = _ref11.past;
  return past ? 'sometime earlier' : 'sometime later';
}

function earlierThisWeek() {
  return 'earlier this week';
}

function earlierLastWeek() {
  return 'earlier last week';
}

function relativeThisWeek(_ref12) {
  var past = _ref12.past,
      when = _ref12.when;
  return past ? earlierThisWeek() : weekdayThisWeek({
    weekday: when.format('en', {
      weekday: 'long'
    })
  });
}

function relativeSecondWeek(_ref13) {
  var past = _ref13.past,
      when = _ref13.when;
  return past ? earlierLastWeek() : weekdayNextWeek({
    weekday: when.format('en', {
      weekday: 'long'
    })
  });
}