"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.rightNow = rightNow;
exports.relativeTicks = relativeTicks;
exports.seconds = seconds;
exports.relativeSeconds = relativeSeconds;
exports.minutes = minutes;
exports.relativeMinutes = relativeMinutes;
exports.hours = hours;
exports.hoursAndMinutes = hoursAndMinutes;
exports.yesterdayOrTommorow = yesterdayOrTommorow;
exports.relativeHoursAndMinutes = relativeHoursAndMinutes;
exports.relativeDelta = relativeDelta;
exports.weekdayThisWeek = weekdayThisWeek;
exports.weekdayNextWeek = weekdayNextWeek;
exports.fewSeconds = fewSeconds;
exports.underMinute = underMinute;
exports.earlierOrLaterToday = earlierOrLaterToday;
exports.earlierOrLater = earlierOrLater;
exports.earlierThisWeek = earlierThisWeek;
exports.earlierLastWeek = earlierLastWeek;
exports.relativeThisWeek = relativeThisWeek;
exports.relativeSecondWeek = relativeSecondWeek;

var _index = require("./index.js");

function rightNow() {
  return 'right now';
}

function relativeTicks({
  past,
  ticks
}) {
  return past ? `${ticks} ago` : `in ${ticks}`;
}

function seconds({
  seconds
}) {
  return `${seconds} ${seconds > 1 ? 'seconds' : 'second'}`;
}

function relativeSeconds(opts) {
  const ticks = seconds({
    seconds: opts.seconds
  });
  return relativeTicks({
    past: opts.past,
    ticks
  });
}

function minutes({
  minutes
}) {
  return `${minutes} ${minutes > 1 ? 'minutes' : 'minute'}`;
}

function relativeMinutes(opts) {
  const ticks = minutes({
    minutes: opts.minutes
  });
  return relativeTicks({
    past: opts.past,
    ticks
  });
}

function hours({
  hours
}) {
  return `${hours} ${hours > 1 ? 'hours' : 'hour'}`;
}

function hoursAndMinutes(opts) {
  return hours(opts) + (opts.minutes ? ' ' + minutes(opts) : '');
}

function yesterdayOrTommorow({
  past
}) {
  return past ? 'yesterday' : 'tomorrow';
}

function relativeHoursAndMinutes(opts) {
  const ticks = hoursAndMinutes({
    hours: opts.hours,
    minutes: opts.minutes
  });
  return relativeTicks({
    past: opts.past,
    ticks
  });
}

function relativeDelta(opts) {
  if (opts.delta < _index.Minute) {
    const seconds = Math.floor(opts.delta / _index.Second);
    if (seconds) return relativeSeconds({
      past: opts.past,
      seconds
    });
  }

  const hours = Math.floor(opts.delta / _index.Hour);
  const minutes = Math.floor((opts.delta - hours * _index.Hour) / _index.Minute);
  if (hours) return relativeHoursAndMinutes({
    past: opts.past,
    hours,
    minutes
  });
  if (minutes) return relativeMinutes({
    past: opts.past,
    minutes
  });
  return rightNow();
}

function weekdayThisWeek({
  weekday
}) {
  return `this ${weekday}`;
}

function weekdayNextWeek({
  weekday
}) {
  return `next ${weekday}`;
}

function fewSeconds({
  past
}) {
  return past ? 'a few seconds ago' : 'in a few seconds';
}

function underMinute({
  past
}) {
  return past ? 'under a minute ago' : 'in under a minute';
}

function earlierOrLaterToday({
  past
}) {
  return past ? 'earlier today' : 'later today';
}

function earlierOrLater({
  past
}) {
  return past ? 'sometime earlier' : 'sometime later';
}

function earlierThisWeek() {
  return 'earlier this week';
}

function earlierLastWeek() {
  return 'earlier last week';
}

function relativeThisWeek({
  past,
  when
}) {
  return past ? earlierThisWeek() : weekdayThisWeek({
    weekday: when.format('en', {
      weekday: 'long'
    })
  });
}

function relativeSecondWeek({
  past,
  when
}) {
  return past ? earlierLastWeek() : weekdayNextWeek({
    weekday: when.format('en', {
      weekday: 'long'
    })
  });
}